
// bibhtml: Generates HTML page (with images) from BibTex files
// See: https://www.telecom-paris.fr/~elc/software/
//
// Copyright 2020 Eric Lecolinet (eric.lecolinet@gmail.com)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include "bibdefs.hpp"

BibTypes BibTypes::instance;
BibFields BibFields::instance;

const char* BibSettings::DefaultStyleFormat =
"%author.\n\
%title.\n\
%journal, %[In %booktitle], %eprint, %howpublished, %volume, %number, \
%[editor (Eds.)], %school, %institution. %publisher %[(%year)]. %pages. %pubstate.\n\
%note.\n\
%award.\n\
%^doi<doi.png> %^url<url.png> %^hal<hal.png> %^pdf<pdf.png> %^video<video.png> \
%?bibcite<bibcite.png> %?keywords %?abstract %^project %^slides %^poster %^software %^link";

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

// add only if not already in the base, name is lowercased
BibTypes::ID BibTypes::addType(const std::string& typeName) {
  return (BibTypes::ID) BibTypes::instance.names.insert(ccuty::tolower(typeName));
}

const std::string& BibTypes::typeName(BibTypes::ID typeID) {
  return BibTypes::instance.names[typeID];       // empty if no match
}

int BibTypes::count() {
  return (int) BibTypes::instance.names.size();
}

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

// add only if not already in the base, name is lowercased
BibFields::ID BibFields::addField(const std::string& name) {
  return (BibFields::ID) BibFields::instance.names.insert(ccuty::tolower(name));
}

BibFields::ID BibFields::fieldID(const std::string& name, bool abbridged) {
  int id = abbridged ?
  BibFields::instance.names.starts_with(ccuty::tolower(name))
  :
  BibFields::instance.names[ccuty::tolower(name)];
  
  return BibFields::ID(id < 0 ? BibFields::none : id);
}

const std::string& BibFields::fieldName(BibFields::ID id) {
  return BibFields::instance.names[id];  // empty if no match
}

